var indexSectionsWithContent =
{
  0: "<_abcdefghijklmnopqrstuvwxyz~",
  1: "_acdfmpt",
  2: "acfmop",
  3: "abcdfgikmnopqrstuw",
  4: "_abcdefgilmnoprstuvwz~",
  5: "_abcdefghijklmnopqrstuvwxyz",
  6: "abcdftu",
  7: "cfl",
  8: "acdefghijklmnopqrstuvwxyz",
  9: "as",
  10: "_bcdefghikmnprtu",
  11: "acdfghimnpstv",
  12: "<abcdefghilmnpqrstuvw"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "groups",
  12: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Modules",
  12: "Pages"
};

